# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbdev_nbs/06_benchmarking.ipynb.

# %% auto 0
__all__ = ['plot_lines', 'plot_points', 'get_tps_fps', 'annotate_dataframe', 'compare_to_reference', 'compare_normalization',
           'print_nonref_hits', 'ResultsTable', 'ResultsTableDirectLFQ', 'ResultsTableIq', 'ResultsTableMaxQuant',
           'ResultsTableMerger', 'OrganismAnnotator', 'OrganismAnnotatorMaxQuant', 'OrganismAnnotatorSpectronaut',
           'OrganismAnnotatorDIANN', 'PlotConfig', 'MultiOrganismIntensityFCPlotter', 'ResultsTableBiological',
           'CVInfoDataset', 'CVDistributionPlotter', 'HistPlotConfig', 'SampleListScaler', 'SampleIndexIQScaler',
           'ScaledDFCreatorDirectLFQFormat', 'ScaledDFCreatorIQFormat', 'LFQTimer', 'TimedLFQRun', 'RuntimeInfo']

# %% ../nbdev_nbs/06_benchmarking.ipynb 1
import matplotlib.pyplot as plt
import numpy as np


def plot_lines(protvals, log = True):
    """plot peptide profiles for a protein"""
    colors = plt.cm.tab20c(np.linspace(0,1,protvals.shape[0]))
    #cmap = plt.get_cmap("tab20c")
    idx = 0
    for row in protvals:
        if not log:
            row = 2**row
        plt.plot(row, c= colors[idx])
        idx+=1
    median_row = np.nanmedian(protvals, axis=0)
    print(median_row)
    plt.plot(median_row, c = 'black',linewidth =3 )
    plt.show()

def plot_points(protvals, log = True):
    colors = plt.cm.tab20c(np.linspace(0,1,protvals.shape[0]))
    #cmap = plt.get_cmap("tab20c")
    idx = 0
    for row in protvals:
        if not log:
            row = 2**row
        x_coord = list(range(len(row)))
        plt.scatter(x_coord,row, c= colors[idx])
        idx+=1

    plt.show()

# %% ../nbdev_nbs/06_benchmarking.ipynb 2
import pandas as pd
def get_tps_fps(result_df, prot2org_file, thresh = 0.05, fc_thresh = 0.3):
    annotated = annotate_dataframe(result_df, prot2org_file)
    condpairs = result_df["condpair"].drop_duplicates()


    for condpair in condpairs:
        annotated_condpair = annotated[annotated["condpair"]==condpair]
        num_tps = sum(annotated_condpair["TP"])
        num_fps = sum(annotated_condpair["FP"])
        annotated_fcfilt = annotated_condpair[annotated["log2fc"] >fc_thresh]
        num_regulated_prots = sum(annotated_fcfilt["fdr"]<thresh)
        num_true_positives = sum(annotated_fcfilt["TP"] &(annotated_fcfilt["fdr"]<0.05))
        num_false_positives = sum(annotated_fcfilt["FP"] &(annotated_fcfilt["fdr"]<0.05))
        fpr = num_false_positives/num_regulated_prots

        print(f'condpair {condpair}')
        print(f"total TPs {num_tps}")
        print(f"total FPs {num_fps}")
        print(f'regulated {num_regulated_prots}')
        print(f'false positives {num_false_positives}')
        print(f'true positives {num_true_positives}')
        print(f'regulated control {num_false_positives+num_true_positives}')
        print(f'FPR {fpr}')

        assert fpr < 0.06


def annotate_dataframe(result_df, prot2org_file):
    prot2org = pd.read_csv(prot2org_file, sep = "\t")
    prot2org["FP"] = (prot2org["organism"] == "Homo sapiens")
    prot2org["TP"] = (prot2org["organism"] == "Saccharomyces cerevisiae")
    prot2org = prot2org[(prot2org["FP"] | prot2org["TP"])]
    print(f"df size before {len(result_df.index)}")
    annotated = pd.merge(result_df, prot2org, how='inner', on = "protein")
    print(f"df size after {len(annotated.index)}")
    return annotated

# %% ../nbdev_nbs/06_benchmarking.ipynb 3
import pandas as pd
import matplotlib.pyplot as plt
def compare_to_reference(result_df, reference_file, condpair):#put in condpair as tuple
    result_df = result_df[result_df["condpair"]==condpair]

    ref_df = pd.read_csv(reference_file, sep = "\t")
    merged = pd.merge(result_df, ref_df, how='inner', on = "protein",suffixes = ["", "_ref"])
    ax_p = merged.plot.scatter(x='pval_ref',y='pval')
    plt.show()
    ax_fc = merged.plot.scatter(x='log2FC_ref',y='fc')
    plt.show()
    ax_fdr = merged.plot.scatter(x='fdr_ref',y='fdr')
    plt.show()

# %% ../nbdev_nbs/06_benchmarking.ipynb 4
import pandas as pd
import matplotlib.pyplot as plt
def compare_normalization(ref_normalization_file, norm1_df, norm2_df):
    ref_normed = pd.read_csv(ref_normalization_file, sep ="\t").set_index('peptide')

    merged = pd.merge(norm1_df, norm2_df, how='inner',  left_index = True, right_index = True)
    columns = merged.columns
    merged = pd.merge(ref_normed, merged, how='inner', left_index = True, right_index = True, suffixes = ["_ref", ""])

    for i in range(len(columns)):
        sample1 = columns[i]
        sample2 = sample1+"_ref"
        ax_p = merged.plot.scatter(x=sample1,y=sample2)
        plt.show()

# %% ../nbdev_nbs/06_benchmarking.ipynb 5
def print_nonref_hits(protein_ref, protein_df, peptide_ref, peptide_df, outdir):
    prots_nonref_df =  protein_df[~(protein_df["protein"].isin(protein_ref["protein"].to_list()))]#the tilde inverts the boolean vector
    peps_nonref_df = peptide_df[~(peptide_df["peptide"].isin(peptide_ref["peptide"].to_list()))]
    prots_nonref_df.to_csv(f"{outdir}/nonref_proteins.tsv", sep = "\t", index = False)
    peps_nonref_df.to_csv(f"{outdir}/nonref_peptides.tsv", sep = "\t", index = False)
    #display(peps_nonref_df)

# %% ../nbdev_nbs/06_benchmarking.ipynb 7
import pandas as pd
import functools


class ResultsTable():
    def __init__(self, input_file, input_name):
        self._input_file = input_file
        self._samples_c1 = None
        self._samples_c2 = None
        self.input_name = input_name
        self.protein_column = "protein"
        self.organism_column = "organism"
        self.log2fc_column = 'log2fc'
        self.mean_intensity_column = 'mean_intensity'
        self.formated_dataframe = None

    
    def get_proteins(self):
        return self.formated_dataframe[self.protein_column]

    def _add_mean_intensity_column(self):
        self._add_median_intensity_columns_for_each_condition()
        self.formated_dataframe[self.mean_intensity_column] = self.formated_dataframe[['median_intensity_c1', 'median_intensity_c2']].mean(axis = 1)

    
    def _add_median_intensity_columns_for_each_condition(self):
        self.formated_dataframe['median_intensity_c1'] = self.formated_dataframe[self._samples_c1].median(axis =1)
        self.formated_dataframe['median_intensity_c2'] = self.formated_dataframe[self._samples_c2].median(axis =1)

    def _add_log2fc_column(self):
        self.formated_dataframe[self.log2fc_column] = [np.log2(x[0]) - np.log2(x[1]) for x in zip(self.formated_dataframe['median_intensity_c1'], self.formated_dataframe['median_intensity_c2'])]




class ResultsTableDirectLFQ(ResultsTable):
    def __init__(self, input_file, input_name,  samples_c1, samples_c2):
        super().__init__(input_file, input_name)
        self._samples_c1 = samples_c1
        self._samples_c2 = samples_c2
        self._define_formatted_dataframe()
        
    def _define_formatted_dataframe(self):
        self._load_directlfq_output()
        self._add_median_intensity_columns_for_each_condition()
        self._add_log2fc_column()
        self._add_mean_intensity_column()
        
    def _load_directlfq_output(self):
        self.formated_dataframe =  pd.read_csv(self._input_file, sep = "\t")


class ResultsTableIq(ResultsTable):
    def __init__(self, input_file, input_name,  samples_c1, samples_c2):
        super().__init__(input_file, input_name)
        self._samples_c1 = samples_c1
        self._samples_c2 = samples_c2
        self._define_formatted_dataframe()
        
    def _define_formatted_dataframe(self):
        self._load_directlfq_output()
        self.formated_dataframe[self._samples_c1+self._samples_c2] = 2**self.formated_dataframe[self._samples_c1 + self._samples_c2]
        self._add_median_intensity_columns_for_each_condition()
        self._add_log2fc_column()
        self._add_mean_intensity_column()
        
    def _load_directlfq_output(self):
        self.formated_dataframe =  pd.read_csv(self._input_file, sep = "\t")




class ResultsTableMaxQuant(ResultsTable):
    def __init__(self, input_file, input_name,  samples_c1, samples_c2):
        super().__init__(input_file, input_name)
        self._samples_c1 = samples_c1
        self._samples_c2 = samples_c2
        self._define_formatted_dataframe()

    
    def _define_formatted_dataframe(self):
        self._load_maxquant_output()
        self._add_median_intensity_columns_for_each_condition()
        self._add_log2fc_column()
        self._add_mean_intensity_column()

    def _load_maxquant_output(self):
        columns_to_use = self._samples_c1 + self._samples_c2 + ["Protein IDs"]
        self.formated_dataframe = pd.read_csv(self._input_file, sep = "\t", usecols=columns_to_use)
        self.formated_dataframe = self.formated_dataframe.rename({'Protein IDs':self.protein_column},axis=1)



# %% ../nbdev_nbs/06_benchmarking.ipynb 8
class ResultsTableMerger():
    def __init__(self, method_name2results_df):
        self._method_name2results_df = method_name2results_df
        self._list_of_tables = []

        self.merged_table = None

        self._define_merged_table()

    def _define_merged_table(self):
        self._collect_list_of_annotated_tables()
        self.merged_table = pd.concat(self._list_of_tables)
        self._filter_merged_table_for_valid_fcs()
    
    def _collect_list_of_annotated_tables(self):
        for method, df in self._method_name2results_df.items():
            self._add_method_column(method, df)
            self._list_of_tables.append(df)

    def _filter_merged_table_for_valid_fcs(self):
        is_valid = [np.isfinite(x) for x in self.merged_table["log2fc"]]
        self.merged_table = self.merged_table[is_valid]

    @staticmethod
    def _add_method_column(method, df):
        df["method"] = method

# %% ../nbdev_nbs/06_benchmarking.ipynb 10
from abc import ABC, abstractmethod

class OrganismAnnotator(ABC):
    def __init__(self, mapping_file, protein_column = 'id', organism_column = 'Species'):
        self._mapping_file = mapping_file
        self._protein_column = protein_column
        self._organism_column = organism_column
        self._protein_organism_mapping_df = self._load_reduce_mapping_dataframe()
        super().__init__()

    def annotate_table_with_organism(self, results_table):

        self.__add_organism_column_to_results_table(results_table)
        self.__filter_non_matching_proteins(results_table)
        

    def save_protein_organism_map(self, outfile):
        self._protein_organism_mapping_df.to_csv(outfile, sep = "\t", index = None)
    
    @abstractmethod
    def _load_reduce_mapping_dataframe(self):
        pass
    
    def _filter_double_mapping_organism(self, protein2organism_df):
        protein2organism_df = protein2organism_df[[";" not in x for x in protein2organism_df[self._organism_column].astype('str')]] #a semicolon seperates different organism entries
        return protein2organism_df

    def __add_organism_column_to_results_table(self, results_table):
        protein2organism_dict = self.__get_protein2organism_dict()
        proteins_resultstable = results_table.formated_dataframe[results_table.protein_column].astype('str')
        results_table.formated_dataframe[results_table.organism_column] = [protein2organism_dict.get(x) for x in proteins_resultstable]

    def __get_protein2organism_dict(self):
        protein2organism = dict(zip(self._protein_organism_mapping_df[self._protein_column].astype('str'), self._protein_organism_mapping_df[self._organism_column]))
        return protein2organism
    
    @staticmethod
    def __filter_non_matching_proteins(results_table):
        list_indicating_if_protein_matches = [x is not None for x in results_table.formated_dataframe[results_table.organism_column]]
        results_table.formated_dataframe = results_table.formated_dataframe[list_indicating_if_protein_matches]
        

# %% ../nbdev_nbs/06_benchmarking.ipynb 11
class OrganismAnnotatorMaxQuant(OrganismAnnotator):
    def __init__(self, mapping_file, protein_column = 'id', organism_column = 'Species'):
        super().__init__(mapping_file=mapping_file, protein_column= protein_column, organism_column= organism_column)
    
    def _load_reduce_mapping_dataframe(self):
        mapping_df = pd.read_csv(self._mapping_file, sep = "\t", usecols=[self._protein_column, self._organism_column], encoding='latin1').drop_duplicates()
        mapping_df = self._filter_double_mapping_organism(mapping_df)
        return mapping_df

# %% ../nbdev_nbs/06_benchmarking.ipynb 12
class OrganismAnnotatorSpectronaut(OrganismAnnotator):
    def __init__(self, mapping_file,protein_column="PG.ProteinGroups", organism_column="PG.Organisms"):
        super().__init__(mapping_file=mapping_file, protein_column= protein_column, organism_column= organism_column)
    
    def _load_reduce_mapping_dataframe(self):
        mapping_df = pd.read_csv(self._mapping_file, sep = "\t", usecols=[self._protein_column, self._organism_column], encoding='latin1').drop_duplicates()
        mapping_df = self._filter_double_mapping_organism(mapping_df)
        return mapping_df

# %% ../nbdev_nbs/06_benchmarking.ipynb 13
class OrganismAnnotatorDIANN(OrganismAnnotator):
    def __init__(self, mapping_file, protein_column = 'Protein.Group', organism_column = 'Protein.Names'):
        super().__init__(mapping_file=mapping_file, protein_column= protein_column, organism_column= organism_column)
    
    def _load_reduce_mapping_dataframe(self):
        mapping_df = pd.read_csv(self._mapping_file, sep = "\t", usecols=[self._protein_column, self._organism_column], encoding='latin1').drop_duplicates()
        mapping_df[self._organism_column] = [self.__get_organism_from_protein_name(x) for x in mapping_df[self._organism_column]]
        mapping_df = mapping_df.drop_duplicates()
        return mapping_df
    
    @staticmethod
    def __get_organism_from_protein_name(protein_name):
        split_name = protein_name.split("_")
        if len(split_name) <2:
            return "None"
        else:
            return split_name[-1]

# %% ../nbdev_nbs/06_benchmarking.ipynb 14
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import directlfq.visualizations as lfq_viz


class PlotConfig():
    def __init__(self, x_axisboundaries = None, y_axisboundaries = None, colormaps = None):
        self.x_axisboundaries = x_axisboundaries
        self.y_axisboundaries = y_axisboundaries
        self._colormaps = colormaps

class MultiOrganismIntensityFCPlotter():
    def __init__(self, ax, resultstable_w_ratios, organisms_to_plot = None, fcs_to_expect = None, title = ""):
        self.ax = ax
        self._color_list_hex = ['#bad566', '#325e7a', '#ffd479']
        self._resultstable_w_ratios = resultstable_w_ratios
        self._organism_column = resultstable_w_ratios.organism_column
        self._log2fc_column = resultstable_w_ratios.log2fc_column
        self._mean_intensity_column = resultstable_w_ratios.mean_intensity_column
        
        self._organisms_to_plot = self._get_organisms_to_plot(organisms_to_plot)
        self._fcs_to_expect = fcs_to_expect

        self._title = self._get_title(title)
        self._scatter_per_organism()
        self._add_expected_lines()

    def _get_organisms_to_plot(self, organisms_to_plot):
        if organisms_to_plot is not None:
            return organisms_to_plot
        else:
            return sorted(list(set(self._resultstable_w_ratios.formated_dataframe[self._organism_column].astype('str'))))
    
    def _get_title(self, title):
        if title !="":
            self._print_infos_about_data()
            return title
        return self._generate_title()

    def _print_infos_about_data(self):
        for organism in self._organisms_to_plot:
            subtable_organism = self._get_organism_subtable(organism)
            print(self._get_stats_of_organism(organism, subtable_organism))

    def _generate_title(self):
        title = ""
        for organism in self._organisms_to_plot:
            subtable_organism = self._get_organism_subtable(organism)
            title += self._get_stats_of_organism(organism, subtable_organism)
        return title

    def _scatter_per_organism(self):
        complete_table = self._resultstable_w_ratios.formated_dataframe.copy()
        complete_table[self._mean_intensity_column] = np.log2(complete_table[self._mean_intensity_column])
        complete_table = self._remove_omitted_organisms_from_table(complete_table)
        color_palette = sns.color_palette(self._color_list_hex, n_colors=len(self._organisms_to_plot))
        sns.scatterplot(data= complete_table, x =self._mean_intensity_column, y= self._log2fc_column, hue=self._organism_column, alpha=0.15, ax=self.ax, 
        hue_order=self._organisms_to_plot, palette=color_palette, size=0.2)
        self.ax.set_title(self._title)
    
    def _remove_omitted_organisms_from_table(self, complete_table):
        row_w_permitted_organism = [x in self._organisms_to_plot for x in complete_table["organism"]]
        return complete_table[row_w_permitted_organism]

    def _add_expected_lines(self):
        if self._fcs_to_expect is not None:
            for idx, fc in enumerate(self._fcs_to_expect):
                color = self._color_list_hex[idx]
                self.ax.axhline(fc, color = color)

    def _get_organism_subtable(self, organism):
        complete_table = self._resultstable_w_ratios.formated_dataframe
        return complete_table[complete_table[self._organism_column] == organism]
    
    def _get_stats_of_organism(self, organism, subtable_organism):
        fcs = subtable_organism[self._log2fc_column].to_numpy()
        fcs = fcs[np.isfinite(fcs)]
        median_fc = np.nanmedian(fcs)
        std_fc = np.nanstd(fcs)
        num_ratios = sum(~np.isnan(fcs))
        return f"{organism} num:{num_ratios} median_FC:{median_fc:.2} STD:{std_fc:.2}\n"
 

# %% ../nbdev_nbs/06_benchmarking.ipynb 16
import pandas as pd
import directlfq.utils as lfq_utils

class ResultsTableBiological():
    def __init__(self, results_file, samplemap, name, protein_id = "protein"):
        self._results_file = results_file
        self._samplemap = samplemap
        self._protein_id = protein_id
        
        self.name = name


        self.results_df = None
        self.cond2samples = {}

        self._load_results_table()
        self._load_cond2samples()

    def _load_results_table(self):
        self.results_df = pd.read_csv(self._results_file, sep = "\t")
        self.results_df = self.results_df[[not x.startswith("REV_") and not x.startswith("CON_") for x in self.results_df[self._protein_id].astype('str')]]
        self.results_df = self.results_df.replace(0, np.nan)
    
    def _load_cond2samples(self):
        samplemap_df = lfq_utils.load_samplemap(self._samplemap)
        for sample, cond in zip(samplemap_df["sample"], samplemap_df["condition"]):
            self.cond2samples[cond] = self.cond2samples.get(cond, []) + [sample]
    

# %% ../nbdev_nbs/06_benchmarking.ipynb 17
import numpy as np
class CVInfoDataset():
    def __init__(self, resultstable_biological, ignore_missing_columns = False):
        self._results_table = resultstable_biological
        self._ignore_missing_columns = ignore_missing_columns
        
        self.name = resultstable_biological.name
        self.cvs = []


        self._calculate_cvs()

    def _calculate_cvs(self):
        for samples in self._results_table.cond2samples.values():
            if self._ignore_missing_columns:
                samples = self._reduce_samples_to_existing_columns(samples)
            self._add_protein_cvs_for_condition(samples)
    
    def _reduce_samples_to_existing_columns(self, samples):
        existing_columns = [x for x in samples if x in self._results_table.results_df.columns]
        return existing_columns

    def _add_protein_cvs_for_condition(self, samples):
        subtable = self._results_table.results_df[samples]
        protein_cvs = subtable.apply(self._cv_function,axis = 1)
        protein_cvs = [x for x in protein_cvs if not np.isnan(x)]
        self.cvs += list(protein_cvs)

    @staticmethod
    def _cv_function(x):
        x = x.to_numpy()
        if sum(~np.isnan(x)) <2:
            return np.nan
        return np.nanstd(x, ddof=1,) / np.nanmean(x) ##ddof ensures that the sample mean std estimate is used

# %% ../nbdev_nbs/06_benchmarking.ipynb 18
import seaborn as sns
import directlfq.visualizations as lfq_viz
class CVDistributionPlotter():
    def __init__(self, list_of_dataset_cv_infos, ax, cumulative=False, histtype='step', density=False, bins=150):
        self._histconfig = HistPlotConfig(cumulative, histtype, density, bins)
        self._list_of_dataset_cv_infos = list_of_dataset_cv_infos
        self._ax  = ax
        self._plot_histograms()

    def _plot_histograms(self):
        self._ax.set_prop_cycle(color = lfq_viz.AlphaPeptColorMap().colorlist_hex)
        for dataset_cv_info in self._list_of_dataset_cv_infos:
            self._add_cv_histogram(dataset_cv_info)

    def _add_cv_histogram(self, dataset_cv_info):
        cvs = dataset_cv_info.cvs
        all_cvs = len(cvs)
        cvs = [x for x in cvs if x<0.75]
        print(f"{all_cvs - len(cvs)} are very large for {dataset_cv_info.name}")
        print(len(cvs))
        print(np.nanmean(cvs))
        print(np.nanmedian(cvs))
        labelname = f"{dataset_cv_info.name} ({all_cvs})"
        color = next(self._ax._get_lines.prop_cycler)["color"]
        self._ax.hist(cvs, label=labelname, cumulative=self._histconfig.cumulative, histtype='stepfilled', density=self._histconfig.density, bins=self._histconfig.bins, linewidth = 1.5, alpha = 0.5, color = color)
        self._ax.hist(cvs, cumulative=self._histconfig.cumulative, histtype='step', density=self._histconfig.density, bins=self._histconfig.bins, linewidth = 1.5, color = color, edgecolor = color)
      

class HistPlotConfig():
    def __init__(self,  cumulative, histtype, density, bins):
        self.cumulative = cumulative
        self.histtype = histtype
        self.density = density
        self.bins = bins

# %% ../nbdev_nbs/06_benchmarking.ipynb 22
import pandas as pd
import directlfq.lfq_manager as lfqmgr
import directlfq.normalization as lfqnorm
import directlfq.protein_intensity_estimation as lfq_protein_estimation
import time
import math


class SampleListScaler():
    def __init__(self, sample_list, desired_number_of_samples):
        self._sample_list = sample_list
        self._desired_number_of_samples = desired_number_of_samples
        
        self.num_replicates_of_sample_list = None
        self.num_remaining_samples = None

        self.scaled_sample_list = []
        self._define_scaled_sample_list()

    def _define_scaled_sample_list(self):
        self._define_number_of_replicates_of_samples()
        self._define_number_of_remaining_samples()
        self._append_replicate_sample_names_to_scaled_sample_list()
        self._append_remaining_sample_names_to_scaled_sample_list()

    def _define_number_of_replicates_of_samples(self):
        num_samples_in_df = len(self._sample_list)
        self.num_replicates_of_sample_list = math.floor(self._desired_number_of_samples/num_samples_in_df)
    
    def _define_number_of_remaining_samples(self):
        num_samples_in_df = len(self._sample_list)
        self.num_remaining_samples = self._desired_number_of_samples%num_samples_in_df

    def _append_replicate_sample_names_to_scaled_sample_list(self):
        for idx in range(self.num_replicates_of_sample_list):
            self.scaled_sample_list += [f"{x}_AND_{idx}" for x in self._sample_list]

    def _append_remaining_sample_names_to_scaled_sample_list(self):
        self.scaled_sample_list +=[f"{self._sample_list[x]}_AND_remainder" for x in range(self.num_remaining_samples)]

    @staticmethod
    def get_original_sample_name(new_sample_name):
        return new_sample_name.split("_AND_")[0]


class SampleIndexIQScaler(SampleListScaler):
    def __init__(self, sample_index_list, desired_number_of_samples):
        self._sample_list = sample_index_list
        self._desired_number_of_samples = desired_number_of_samples
        self.scaled_sample_list = []
        
    def _append_replicate_sample_names_to_scaled_sample_list(self):
        for idx in range(self._num_replicates_of_sample_list):
            offset_to_zero_idx = len(set(self._sample_list))*idx
            self.scaled_sample_list += [ x + offset_to_zero_idx for x in self._sample_list]

    def _append_remaining_sample_names_to_scaled_sample_list(self):
        offset_to_zero_idx = self.scaled_sample_list[-1]+1
        self.scaled_sample_list +=[x + offset_to_zero_idx for x in range(self._num_remaining_samples)]


class ScaledDFCreatorDirectLFQFormat():
    def __init__(self, template_df, desired_number_of_samples):
        self._template_df = template_df
        self._column_names = list(self._template_df.columns)
        self._samplelist_scaler = SampleListScaler(self._column_names, desired_number_of_samples)         
        self.scaled_df = None
        self._create_scaled_dataframe()

    def _create_scaled_dataframe(self):
        template_dataframe_dict = self._template_df.to_dict(orient = 'list')
        input_dataframe_dict = {x : template_dataframe_dict.get(self._samplelist_scaler.get_original_sample_name(x))  for x in self._samplelist_scaler.scaled_sample_list}
        self.scaled_df = pd.DataFrame(input_dataframe_dict, index=self._template_df.index)


from io import BytesIO
from csv import writer 
import pandas as pd

class ScaledDFCreatorIQFormat():
    def __init__(self, quant_df, sample_list_df, desired_number_of_samples):
        self._quant_df = quant_df
        self._sample_list = sample_list_df["sample_list"]
        self._desired_number_of_samples = desired_number_of_samples
        self._samplelist_scaler = None

        self.scaled_quant_df = None

        self._create_scaled_quant_df()
        self._create_scaled_sample_list_df()

    def _create_scaled_quant_df(self):
        self._create_indexes_to_expand_quant_df()
        self._quant_df = self._quant_df.set_index("sample_list")#.loc[self._indexes_to_expand_quant_df]
        
        self.scaled_quant_df = self._get_scaled_quant_df(self._indexes_to_expand_quant_df)
        self.scaled_quant_df["sample_list"] = self._get_new_samples_column()
        self.scaled_quant_df = self.scaled_quant_df.reset_index(drop= True)

    def _get_scaled_quant_df(self, indexes):
        list_of_sub_dfs = []
        for idx in indexes:
            rows = pd.DataFrame(self._quant_df.loc[[idx]])
            list_of_sub_dfs.append(rows)

        return pd.concat(list_of_sub_dfs)

    def _create_scaled_sample_list_df(self):
        self._samplelist_scaler = SampleListScaler(sample_list = self._sample_list, desired_number_of_samples= len(set(self.scaled_quant_df["sample_list"])))
        self.scaled_sample_list_df = pd.DataFrame({"sample_list" : self._samplelist_scaler.scaled_sample_list})

    def _create_indexes_to_expand_quant_df(self):
        num_scaled_samples = self._desired_number_of_samples
        num_samples = len(self._sample_list)
        indexes_of_scaled_sample_list = list(range(num_scaled_samples))
        self._indexes_to_expand_quant_df = [x%num_samples+1 for x in indexes_of_scaled_sample_list]

    def _get_new_samples_column(self):
        scaled_repeated_sample_list = self.scaled_quant_df.index
        previous_sample = scaled_repeated_sample_list[0]
        new_sample_list = [1]

        sample_id = 1
        for sample in scaled_repeated_sample_list[1:]:
            if sample != previous_sample:
                sample_id +=1
                previous_sample = sample
            new_sample_list.append(sample_id)
            
        return new_sample_list
    

# %% ../nbdev_nbs/06_benchmarking.ipynb 26
import pandas as pd
import directlfq.utils as lfq_utils

class LFQTimer():
    def __init__(self, template_file, list_of_samplenumbers_to_check, name):
        self._template_file = template_file
        self._samplenumbers_to_check = list_of_samplenumbers_to_check
        self._name = name
        self._template_df = None
        self._read_template_file()
        self.timed_lfq_runs = []
        self._iterate_through_sizes()
    
    def _read_template_file(self):
        self._template_df = pd.read_csv(self._template_file, sep = "\t")
        self._template_df = lfq_utils.index_and_log_transform_input_df(self._template_df)

    def _iterate_through_sizes(self):
        for samplenumber in self._samplenumbers_to_check:
            formatted_df = ScaledDFCreatorDirectLFQFormat(self._template_df, desired_number_of_samples=samplenumber).scaled_df
            self.timed_lfq_runs.append(TimedLFQRun(formatted_df,self._name).run_from_formatted_df())

# %% ../nbdev_nbs/06_benchmarking.ipynb 27
class TimedLFQRun():
    def __init__(self, formatted_df, name):
        self.name = name
        self.runtime_info = RuntimeInfo()
        self.num_samples = len(formatted_df.columns)
        self._formatted_df = formatted_df

    def run_from_formatted_df(self):
        self.runtime_info._start_samplenorm = time.time()
        input_df_normed = lfqnorm.NormalizationManagerSamples(self._formatted_df, num_samples_quadratic=50).complete_dataframe
        self.runtime_info._end_samplenorm = time.time()
        self.runtime_info._start_protein_norm = time.time()
        lfq_protein_estimation.estimate_protein_intensities(input_df_normed,min_nonan=1, num_samples_quadratic=10, num_cores=None)
        self.runtime_info._end_protein_norm = time.time()
        self.runtime_info.calculate_runtimes()
        return self

class RuntimeInfo():
    def __init__(self):
        self._start_samplenorm= None
        self._end_samplenorm = None
        self._start_protein_norm = None
        self._end_protein_norm = None

        self.overall_runtime = None
        self.runtime_samplenorm = None
        self.runtime_protein_norm = None

    def calculate_runtimes(self):
        self.overall_runtime = (self._end_protein_norm - self._start_samplenorm)/60
        self.runtime_samplenorm = (self._end_samplenorm - self._start_samplenorm)/60
        self.runtime_protein_norm = (self._end_protein_norm - self._start_protein_norm)/60



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/directlfq/',
                'doc_host': 'https://ammarcsj.github.io',
                'git_url': 'https://github.com/ammarcsj/directlfq/tree/master/',
                'lib_path': 'directlfq'},
  'syms': { 'directlfq.benchmarking': { 'directlfq.benchmarking.CVDistributionPlotter': ( 'benchmarking.html#cvdistributionplotter',
                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVDistributionPlotter.__init__': ( 'benchmarking.html#cvdistributionplotter.__init__',
                                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVDistributionPlotter._add_cv_histogram': ( 'benchmarking.html#cvdistributionplotter._add_cv_histogram',
                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVDistributionPlotter._plot_histograms': ( 'benchmarking.html#cvdistributionplotter._plot_histograms',
                                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset': ( 'benchmarking.html#cvinfodataset',
                                                                                  'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset.__init__': ( 'benchmarking.html#cvinfodataset.__init__',
                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset._add_protein_cvs_for_condition': ( 'benchmarking.html#cvinfodataset._add_protein_cvs_for_condition',
                                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset._calculate_cvs': ( 'benchmarking.html#cvinfodataset._calculate_cvs',
                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset._cv_function': ( 'benchmarking.html#cvinfodataset._cv_function',
                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.CVInfoDataset._reduce_samples_to_existing_columns': ( 'benchmarking.html#cvinfodataset._reduce_samples_to_existing_columns',
                                                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.HistPlotConfig': ( 'benchmarking.html#histplotconfig',
                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.HistPlotConfig.__init__': ( 'benchmarking.html#histplotconfig.__init__',
                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.LFQTimer': ('benchmarking.html#lfqtimer', 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.LFQTimer.__init__': ( 'benchmarking.html#lfqtimer.__init__',
                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.LFQTimer._iterate_through_sizes': ( 'benchmarking.html#lfqtimer._iterate_through_sizes',
                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.LFQTimer._read_template_file': ( 'benchmarking.html#lfqtimer._read_template_file',
                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter': ( 'benchmarking.html#multiorganismintensityfcplotter',
                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter.__init__': ( 'benchmarking.html#multiorganismintensityfcplotter.__init__',
                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._add_expected_lines': ( 'benchmarking.html#multiorganismintensityfcplotter._add_expected_lines',
                                                                                                                        'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._generate_title': ( 'benchmarking.html#multiorganismintensityfcplotter._generate_title',
                                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._get_organism_subtable': ( 'benchmarking.html#multiorganismintensityfcplotter._get_organism_subtable',
                                                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._get_organisms_to_plot': ( 'benchmarking.html#multiorganismintensityfcplotter._get_organisms_to_plot',
                                                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._get_stats_of_organism': ( 'benchmarking.html#multiorganismintensityfcplotter._get_stats_of_organism',
                                                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._get_title': ( 'benchmarking.html#multiorganismintensityfcplotter._get_title',
                                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._print_infos_about_data': ( 'benchmarking.html#multiorganismintensityfcplotter._print_infos_about_data',
                                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._remove_omitted_organisms_from_table': ( 'benchmarking.html#multiorganismintensityfcplotter._remove_omitted_organisms_from_table',
                                                                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.MultiOrganismIntensityFCPlotter._scatter_per_organism': ( 'benchmarking.html#multiorganismintensityfcplotter._scatter_per_organism',
                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator': ( 'benchmarking.html#organismannotator',
                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.__add_organism_column_to_results_table': ( 'benchmarking.html#organismannotator.__add_organism_column_to_results_table',
                                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.__filter_non_matching_proteins': ( 'benchmarking.html#organismannotator.__filter_non_matching_proteins',
                                                                                                                     'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.__get_protein2organism_dict': ( 'benchmarking.html#organismannotator.__get_protein2organism_dict',
                                                                                                                  'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.__init__': ( 'benchmarking.html#organismannotator.__init__',
                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator._filter_double_mapping_organism': ( 'benchmarking.html#organismannotator._filter_double_mapping_organism',
                                                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator._load_reduce_mapping_dataframe': ( 'benchmarking.html#organismannotator._load_reduce_mapping_dataframe',
                                                                                                                     'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.annotate_table_with_organism': ( 'benchmarking.html#organismannotator.annotate_table_with_organism',
                                                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotator.save_protein_organism_map': ( 'benchmarking.html#organismannotator.save_protein_organism_map',
                                                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorDIANN': ( 'benchmarking.html#organismannotatordiann',
                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorDIANN.__get_organism_from_protein_name': ( 'benchmarking.html#organismannotatordiann.__get_organism_from_protein_name',
                                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorDIANN.__init__': ( 'benchmarking.html#organismannotatordiann.__init__',
                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorDIANN._load_reduce_mapping_dataframe': ( 'benchmarking.html#organismannotatordiann._load_reduce_mapping_dataframe',
                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorMaxQuant': ( 'benchmarking.html#organismannotatormaxquant',
                                                                                              'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorMaxQuant.__init__': ( 'benchmarking.html#organismannotatormaxquant.__init__',
                                                                                                       'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorMaxQuant._load_reduce_mapping_dataframe': ( 'benchmarking.html#organismannotatormaxquant._load_reduce_mapping_dataframe',
                                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorSpectronaut': ( 'benchmarking.html#organismannotatorspectronaut',
                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorSpectronaut.__init__': ( 'benchmarking.html#organismannotatorspectronaut.__init__',
                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.OrganismAnnotatorSpectronaut._load_reduce_mapping_dataframe': ( 'benchmarking.html#organismannotatorspectronaut._load_reduce_mapping_dataframe',
                                                                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.PlotConfig': ('benchmarking.html#plotconfig', 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.PlotConfig.__init__': ( 'benchmarking.html#plotconfig.__init__',
                                                                                        'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable': ( 'benchmarking.html#resultstable',
                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable.__init__': ( 'benchmarking.html#resultstable.__init__',
                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable._add_log2fc_column': ( 'benchmarking.html#resultstable._add_log2fc_column',
                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable._add_mean_intensity_column': ( 'benchmarking.html#resultstable._add_mean_intensity_column',
                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable._add_median_intensity_columns_for_each_condition': ( 'benchmarking.html#resultstable._add_median_intensity_columns_for_each_condition',
                                                                                                                                  'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTable.get_proteins': ( 'benchmarking.html#resultstable.get_proteins',
                                                                                              'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableBiological': ( 'benchmarking.html#resultstablebiological',
                                                                                           'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableBiological.__init__': ( 'benchmarking.html#resultstablebiological.__init__',
                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableBiological._load_cond2samples': ( 'benchmarking.html#resultstablebiological._load_cond2samples',
                                                                                                              'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableBiological._load_results_table': ( 'benchmarking.html#resultstablebiological._load_results_table',
                                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableDirectLFQ': ( 'benchmarking.html#resultstabledirectlfq',
                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableDirectLFQ.__init__': ( 'benchmarking.html#resultstabledirectlfq.__init__',
                                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableDirectLFQ._define_formatted_dataframe': ( 'benchmarking.html#resultstabledirectlfq._define_formatted_dataframe',
                                                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableDirectLFQ._load_directlfq_output': ( 'benchmarking.html#resultstabledirectlfq._load_directlfq_output',
                                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableIq': ( 'benchmarking.html#resultstableiq',
                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableIq.__init__': ( 'benchmarking.html#resultstableiq.__init__',
                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableIq._define_formatted_dataframe': ( 'benchmarking.html#resultstableiq._define_formatted_dataframe',
                                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableIq._load_directlfq_output': ( 'benchmarking.html#resultstableiq._load_directlfq_output',
                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMaxQuant': ( 'benchmarking.html#resultstablemaxquant',
                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMaxQuant.__init__': ( 'benchmarking.html#resultstablemaxquant.__init__',
                                                                                                  'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMaxQuant._define_formatted_dataframe': ( 'benchmarking.html#resultstablemaxquant._define_formatted_dataframe',
                                                                                                                     'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMaxQuant._load_maxquant_output': ( 'benchmarking.html#resultstablemaxquant._load_maxquant_output',
                                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger': ( 'benchmarking.html#resultstablemerger',
                                                                                       'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger.__init__': ( 'benchmarking.html#resultstablemerger.__init__',
                                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger._add_method_column': ( 'benchmarking.html#resultstablemerger._add_method_column',
                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger._collect_list_of_annotated_tables': ( 'benchmarking.html#resultstablemerger._collect_list_of_annotated_tables',
                                                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger._define_merged_table': ( 'benchmarking.html#resultstablemerger._define_merged_table',
                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ResultsTableMerger._filter_merged_table_for_valid_fcs': ( 'benchmarking.html#resultstablemerger._filter_merged_table_for_valid_fcs',
                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.RuntimeInfo': ( 'benchmarking.html#runtimeinfo',
                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.RuntimeInfo.__init__': ( 'benchmarking.html#runtimeinfo.__init__',
                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.RuntimeInfo.calculate_runtimes': ( 'benchmarking.html#runtimeinfo.calculate_runtimes',
                                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleIndexIQScaler': ( 'benchmarking.html#sampleindexiqscaler',
                                                                                        'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleIndexIQScaler.__init__': ( 'benchmarking.html#sampleindexiqscaler.__init__',
                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleIndexIQScaler._append_remaining_sample_names_to_scaled_sample_list': ( 'benchmarking.html#sampleindexiqscaler._append_remaining_sample_names_to_scaled_sample_list',
                                                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleIndexIQScaler._append_replicate_sample_names_to_scaled_sample_list': ( 'benchmarking.html#sampleindexiqscaler._append_replicate_sample_names_to_scaled_sample_list',
                                                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler': ( 'benchmarking.html#samplelistscaler',
                                                                                     'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler.__init__': ( 'benchmarking.html#samplelistscaler.__init__',
                                                                                              'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler._append_remaining_sample_names_to_scaled_sample_list': ( 'benchmarking.html#samplelistscaler._append_remaining_sample_names_to_scaled_sample_list',
                                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler._append_replicate_sample_names_to_scaled_sample_list': ( 'benchmarking.html#samplelistscaler._append_replicate_sample_names_to_scaled_sample_list',
                                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler._define_number_of_remaining_samples': ( 'benchmarking.html#samplelistscaler._define_number_of_remaining_samples',
                                                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler._define_number_of_replicates_of_samples': ( 'benchmarking.html#samplelistscaler._define_number_of_replicates_of_samples',
                                                                                                                             'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler._define_scaled_sample_list': ( 'benchmarking.html#samplelistscaler._define_scaled_sample_list',
                                                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.SampleListScaler.get_original_sample_name': ( 'benchmarking.html#samplelistscaler.get_original_sample_name',
                                                                                                              'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorDirectLFQFormat': ( 'benchmarking.html#scaleddfcreatordirectlfqformat',
                                                                                                   'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorDirectLFQFormat.__init__': ( 'benchmarking.html#scaleddfcreatordirectlfqformat.__init__',
                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorDirectLFQFormat._create_scaled_dataframe': ( 'benchmarking.html#scaleddfcreatordirectlfqformat._create_scaled_dataframe',
                                                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat': ( 'benchmarking.html#scaleddfcreatoriqformat',
                                                                                            'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat.__init__': ( 'benchmarking.html#scaleddfcreatoriqformat.__init__',
                                                                                                     'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat._create_indexes_to_expand_quant_df': ( 'benchmarking.html#scaleddfcreatoriqformat._create_indexes_to_expand_quant_df',
                                                                                                                               'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat._create_scaled_quant_df': ( 'benchmarking.html#scaleddfcreatoriqformat._create_scaled_quant_df',
                                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat._create_scaled_sample_list_df': ( 'benchmarking.html#scaleddfcreatoriqformat._create_scaled_sample_list_df',
                                                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat._get_new_samples_column': ( 'benchmarking.html#scaleddfcreatoriqformat._get_new_samples_column',
                                                                                                                    'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.ScaledDFCreatorIQFormat._get_scaled_quant_df': ( 'benchmarking.html#scaleddfcreatoriqformat._get_scaled_quant_df',
                                                                                                                 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.TimedLFQRun': ( 'benchmarking.html#timedlfqrun',
                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.TimedLFQRun.__init__': ( 'benchmarking.html#timedlfqrun.__init__',
                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.TimedLFQRun.run_from_formatted_df': ( 'benchmarking.html#timedlfqrun.run_from_formatted_df',
                                                                                                      'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.annotate_dataframe': ( 'benchmarking.html#annotate_dataframe',
                                                                                       'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.compare_normalization': ( 'benchmarking.html#compare_normalization',
                                                                                          'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.compare_to_reference': ( 'benchmarking.html#compare_to_reference',
                                                                                         'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.get_tps_fps': ( 'benchmarking.html#get_tps_fps',
                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.plot_lines': ('benchmarking.html#plot_lines', 'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.plot_points': ( 'benchmarking.html#plot_points',
                                                                                'directlfq/benchmarking.py'),
                                        'directlfq.benchmarking.print_nonref_hits': ( 'benchmarking.html#print_nonref_hits',
                                                                                      'directlfq/benchmarking.py')},
            'directlfq.cli': {},
            'directlfq.dashboard_parts': {},
            'directlfq.gui': {},
            'directlfq.gui_textfields': {},
            'directlfq.lfq_manager': { 'directlfq.lfq_manager.get_outfile_basename': ( 'lfq_manager.html#get_outfile_basename',
                                                                                       'directlfq/lfq_manager.py'),
                                       'directlfq.lfq_manager.prepare_input_filename': ( 'lfq_manager.html#prepare_input_filename',
                                                                                         'directlfq/lfq_manager.py'),
                                       'directlfq.lfq_manager.run_lfq': ('lfq_manager.html#run_lfq', 'directlfq/lfq_manager.py'),
                                       'directlfq.lfq_manager.save_ion_df': ('lfq_manager.html#save_ion_df', 'directlfq/lfq_manager.py'),
                                       'directlfq.lfq_manager.save_protein_df': ( 'lfq_manager.html#save_protein_df',
                                                                                  'directlfq/lfq_manager.py')},
            'directlfq.normalization': { 'directlfq.normalization.NormalizationManager': ( 'normalization.html#normalizationmanager',
                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager.__init__': ( 'normalization.html#normalizationmanager.__init__',
                                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._create_reference_sample': ( 'normalization.html#normalizationmanager._create_reference_sample',
                                                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._determine_sorted_rows': ( 'normalization.html#normalizationmanager._determine_sorted_rows',
                                                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._determine_subset_rows': ( 'normalization.html#normalizationmanager._determine_subset_rows',
                                                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._get_num_nas_in_row': ( 'normalization.html#normalizationmanager._get_num_nas_in_row',
                                                                                                               'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._normalize_complete_input_quadratic': ( 'normalization.html#normalizationmanager._normalize_complete_input_quadratic',
                                                                                                                               'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._normalize_quadratic_and_linear': ( 'normalization.html#normalizationmanager._normalize_quadratic_and_linear',
                                                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._normalize_quadratic_selection': ( 'normalization.html#normalizationmanager._normalize_quadratic_selection',
                                                                                                                          'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._run_normalization': ( 'normalization.html#normalizationmanager._run_normalization',
                                                                                                              'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManager._shift_remaining_dataframe_to_reference_sample': ( 'normalization.html#normalizationmanager._shift_remaining_dataframe_to_reference_sample',
                                                                                                                                          'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerProtein': ( 'normalization.html#normalizationmanagerprotein',
                                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerProtein.__init__': ( 'normalization.html#normalizationmanagerprotein.__init__',
                                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamples': ( 'normalization.html#normalizationmanagersamples',
                                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamples.__init__': ( 'normalization.html#normalizationmanagersamples.__init__',
                                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins': ( 'normalization.html#normalizationmanagersamplesonselectedproteins',
                                                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins.__init__': ( 'normalization.html#normalizationmanagersamplesonselectedproteins.__init__',
                                                                                                                             'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins._adapt_selected_proteins_to_protein_groups': ( 'normalization.html#normalizationmanagersamplesonselectedproteins._adapt_selected_proteins_to_protein_groups',
                                                                                                                                                               'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins._create_reference_sample': ( 'normalization.html#normalizationmanagersamplesonselectedproteins._create_reference_sample',
                                                                                                                                             'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins._get_protein2proteingroup_mapping': ( 'normalization.html#normalizationmanagersamplesonselectedproteins._get_protein2proteingroup_mapping',
                                                                                                                                                      'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins._normalization_function': ( 'normalization.html#normalizationmanagersamplesonselectedproteins._normalization_function',
                                                                                                                                            'directlfq/normalization.py'),
                                         'directlfq.normalization.NormalizationManagerSamplesOnSelectedProteins._shift_remaining_dataframe_to_reference_sample': ( 'normalization.html#normalizationmanagersamplesonselectedproteins._shift_remaining_dataframe_to_reference_sample',
                                                                                                                                                                   'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear': ( 'normalization.html#sampleshifterlinear',
                                                                                          'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear.__init__': ( 'normalization.html#sampleshifterlinear.__init__',
                                                                                                   'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear._calc_distance': ( 'normalization.html#sampleshifterlinear._calc_distance',
                                                                                                         'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear._define_ion_dataframe_values': ( 'normalization.html#sampleshifterlinear._define_ion_dataframe_values',
                                                                                                                       'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear._shift_columns_to_reference_sample': ( 'normalization.html#sampleshifterlinear._shift_columns_to_reference_sample',
                                                                                                                             'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear._shift_to_reference_sample': ( 'normalization.html#sampleshifterlinear._shift_to_reference_sample',
                                                                                                                     'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinear._update_ion_dataframe': ( 'normalization.html#sampleshifterlinear._update_ion_dataframe',
                                                                                                                'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinearToMedian': ( 'normalization.html#sampleshifterlineartomedian',
                                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinearToMedian.__init__': ( 'normalization.html#sampleshifterlineartomedian.__init__',
                                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.SampleShifterLinearToMedian._shift_to_median': ( 'normalization.html#sampleshifterlineartomedian._shift_to_median',
                                                                                                                   'directlfq/normalization.py'),
                                         'directlfq.normalization.apply_sampleshifts': ( 'normalization.html#apply_sampleshifts',
                                                                                         'directlfq/normalization.py'),
                                         'directlfq.normalization.calc_distance': ( 'normalization.html#calc_distance',
                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.calc_nanmedian': ( 'normalization.html#calc_nanmedian',
                                                                                     'directlfq/normalization.py'),
                                         'directlfq.normalization.calc_nanvar': ( 'normalization.html#calc_nanvar',
                                                                                  'directlfq/normalization.py'),
                                         'directlfq.normalization.calculate_fraction_with_no_NAs': ( 'normalization.html#calculate_fraction_with_no_nas',
                                                                                                     'directlfq/normalization.py'),
                                         'directlfq.normalization.create_distance_matrix': ( 'normalization.html#create_distance_matrix',
                                                                                             'directlfq/normalization.py'),
                                         'directlfq.normalization.determine_anchor_and_shift_sample': ( 'normalization.html#determine_anchor_and_shift_sample',
                                                                                                        'directlfq/normalization.py'),
                                         'directlfq.normalization.drop_nas_if_possible': ( 'normalization.html#drop_nas_if_possible',
                                                                                           'directlfq/normalization.py'),
                                         'directlfq.normalization.get_bestmatch_pair': ( 'normalization.html#get_bestmatch_pair',
                                                                                         'directlfq/normalization.py'),
                                         'directlfq.normalization.get_fcdistrib': ( 'normalization.html#get_fcdistrib',
                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.get_normfacts': ( 'normalization.html#get_normfacts',
                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.get_total_shift': ( 'normalization.html#get_total_shift',
                                                                                      'directlfq/normalization.py'),
                                         'directlfq.normalization.merge_distribs': ( 'normalization.html#merge_distribs',
                                                                                     'directlfq/normalization.py'),
                                         'directlfq.normalization.normalize_dataframe_between_samples': ( 'normalization.html#normalize_dataframe_between_samples',
                                                                                                          'directlfq/normalization.py'),
                                         'directlfq.normalization.normalize_ion_profiles': ( 'normalization.html#normalize_ion_profiles',
                                                                                             'directlfq/normalization.py'),
                                         'directlfq.normalization.set_samples_with_only_single_intensity_to_nan': ( 'normalization.html#set_samples_with_only_single_intensity_to_nan',
                                                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.shift_samples': ( 'normalization.html#shift_samples',
                                                                                    'directlfq/normalization.py'),
                                         'directlfq.normalization.update_distance_matrix': ( 'normalization.html#update_distance_matrix',
                                                                                             'directlfq/normalization.py')},
            'directlfq.protein_intensity_estimation': { 'directlfq.protein_intensity_estimation.IonCheckedForOrphan': ( 'protein_intensity_estimation.html#ioncheckedfororphan',
                                                                                                                        'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.IonCheckedForOrphan.__init__': ( 'protein_intensity_estimation.html#ioncheckedfororphan.__init__',
                                                                                                                                 'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.IonCheckedForOrphan._check_if_is_orphan': ( 'protein_intensity_estimation.html#ioncheckedfororphan._check_if_is_orphan',
                                                                                                                                            'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.IonCheckedForOrphan._define_count_of_nonans_per_position_for_ion': ( 'protein_intensity_estimation.html#ioncheckedfororphan._define_count_of_nonans_per_position_for_ion',
                                                                                                                                                                     'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.IonCheckedForOrphan._define_num_nonans': ( 'protein_intensity_estimation.html#ioncheckedfororphan._define_num_nonans',
                                                                                                                                           'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover': ( 'protein_intensity_estimation.html#orphanionremover',
                                                                                                                     'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover.__init__': ( 'protein_intensity_estimation.html#orphanionremover.__init__',
                                                                                                                              'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover._append_to_orphan_or_non_orphan_list': ( 'protein_intensity_estimation.html#orphanionremover._append_to_orphan_or_non_orphan_list',
                                                                                                                                                          'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover._define_count_of_nonans_per_position': ( 'protein_intensity_estimation.html#orphanionremover._define_count_of_nonans_per_position',
                                                                                                                                                          'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover._define_orphan_ions_and_non_orphan_ions': ( 'protein_intensity_estimation.html#orphanionremover._define_orphan_ions_and_non_orphan_ions',
                                                                                                                                                             'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover._define_orphan_removed_df': ( 'protein_intensity_estimation.html#orphanionremover._define_orphan_removed_df',
                                                                                                                                               'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonRemover._define_protvals_is_not_na_df': ( 'protein_intensity_estimation.html#orphanionremover._define_protvals_is_not_na_df',
                                                                                                                                                   'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonsForDeletionSelector': ( 'protein_intensity_estimation.html#orphanionsfordeletionselector',
                                                                                                                                  'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonsForDeletionSelector.__init__': ( 'protein_intensity_estimation.html#orphanionsfordeletionselector.__init__',
                                                                                                                                           'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonsForDeletionSelector._define_orphan_ions_for_deletion': ( 'protein_intensity_estimation.html#orphanionsfordeletionselector._define_orphan_ions_for_deletion',
                                                                                                                                                                   'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonsForDeletionSelector._get_accessions_of_list_of_ions': ( 'protein_intensity_estimation.html#orphanionsfordeletionselector._get_accessions_of_list_of_ions',
                                                                                                                                                                  'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.OrphanIonsForDeletionSelector._sort_list_of_ions_by_num_nonans_descending': ( 'protein_intensity_estimation.html#orphanionsfordeletionselector._sort_list_of_ions_by_num_nonans_descending',
                                                                                                                                                                              'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter': ( 'protein_intensity_estimation.html#protvalcutter',
                                                                                                                  'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter.__init__': ( 'protein_intensity_estimation.html#protvalcutter.__init__',
                                                                                                                           'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter._check_if_df_too_long_and_sort_index_if_so': ( 'protein_intensity_estimation.html#protvalcutter._check_if_df_too_long_and_sort_index_if_so',
                                                                                                                                                             'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter._determine_nansorted_df_index': ( 'protein_intensity_estimation.html#protvalcutter._determine_nansorted_df_index',
                                                                                                                                                'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter._get_num_nas_in_row': ( 'protein_intensity_estimation.html#protvalcutter._get_num_nas_in_row',
                                                                                                                                      'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter._get_shortened_dataframe': ( 'protein_intensity_estimation.html#protvalcutter._get_shortened_dataframe',
                                                                                                                                           'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.ProtvalCutter.get_dataframe': ( 'protein_intensity_estimation.html#protvalcutter.get_dataframe',
                                                                                                                                'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.add_protein_name_to_ion_df': ( 'protein_intensity_estimation.html#add_protein_name_to_ion_df',
                                                                                                                               'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.add_protein_names_to_ion_ints': ( 'protein_intensity_estimation.html#add_protein_names_to_ion_ints',
                                                                                                                                  'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.calculate_peptide_and_protein_intensities': ( 'protein_intensity_estimation.html#calculate_peptide_and_protein_intensities',
                                                                                                                                              'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.estimate_protein_intensities': ( 'protein_intensity_estimation.html#estimate_protein_intensities',
                                                                                                                                 'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_configured_multiprocessing_pool': ( 'protein_intensity_estimation.html#get_configured_multiprocessing_pool',
                                                                                                                                        'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_input_specification_tuplelist_idx__df__num_samples_quadratic__min_nonan': ( 'protein_intensity_estimation.html#get_input_specification_tuplelist_idx__df__num_samples_quadratic__min_nonan',
                                                                                                                                                                                'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_ion_intensity_dataframe_from_list_of_shifted_peptides': ( 'protein_intensity_estimation.html#get_ion_intensity_dataframe_from_list_of_shifted_peptides',
                                                                                                                                                              'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_list_of_tuple_w_protein_profiles_and_shifted_peptides': ( 'protein_intensity_estimation.html#get_list_of_tuple_w_protein_profiles_and_shifted_peptides',
                                                                                                                                                              'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_list_with_multiprocessing': ( 'protein_intensity_estimation.html#get_list_with_multiprocessing',
                                                                                                                                  'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_list_with_protein_value_for_each_sample': ( 'protein_intensity_estimation.html#get_list_with_protein_value_for_each_sample',
                                                                                                                                                'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_list_with_sequential_processing': ( 'protein_intensity_estimation.html#get_list_with_sequential_processing',
                                                                                                                                        'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_normed_dfs': ( 'protein_intensity_estimation.html#get_normed_dfs',
                                                                                                                   'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_protein_dataframe_from_list_of_protein_profiles': ( 'protein_intensity_estimation.html#get_protein_dataframe_from_list_of_protein_profiles',
                                                                                                                                                        'directlfq/protein_intensity_estimation.py'),
                                                        'directlfq.protein_intensity_estimation.get_protein_profile_from_shifted_peptides': ( 'protein_intensity_estimation.html#get_protein_profile_from_shifted_peptides',
                                                                                                                                              'directlfq/protein_intensity_estimation.py')},
            'directlfq.testfile_handling': { 'directlfq.testfile_handling.DownloadLinkConverter': ( 'testfile_handling.html#downloadlinkconverter',
                                                                                                    'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__check_if_value_is_dict__': ( 'testfile_handling.html#downloadlinkconverter.__check_if_value_is_dict__',
                                                                                                                               'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__convert_nested_dict_to_relpath_dict__': ( 'testfile_handling.html#downloadlinkconverter.__convert_nested_dict_to_relpath_dict__',
                                                                                                                                            'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__get_updated_relpath__': ( 'testfile_handling.html#downloadlinkconverter.__get_updated_relpath__',
                                                                                                                            'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__init__': ( 'testfile_handling.html#downloadlinkconverter.__init__',
                                                                                                             'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__load_dict_from_yaml_file__': ( 'testfile_handling.html#downloadlinkconverter.__load_dict_from_yaml_file__',
                                                                                                                                 'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__recursively_call_sub_dictionary__': ( 'testfile_handling.html#downloadlinkconverter.__recursively_call_sub_dictionary__',
                                                                                                                                        'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.__yield_path2link_pair__': ( 'testfile_handling.html#downloadlinkconverter.__yield_path2link_pair__',
                                                                                                                             'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.DownloadLinkConverter.get_path2link_from_yaml_file': ( 'testfile_handling.html#downloadlinkconverter.get_path2link_from_yaml_file',
                                                                                                                                 'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader': ( 'testfile_handling.html#testfolderdownloader',
                                                                                                   'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__convert_relative_to_absolute_path__': ( 'testfile_handling.html#testfolderdownloader.__convert_relative_to_absolute_path__',
                                                                                                                                         'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__convert_to_relative_paths__': ( 'testfile_handling.html#testfolderdownloader.__convert_to_relative_paths__',
                                                                                                                                 'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__download_and_extract_compressed_file__': ( 'testfile_handling.html#testfolderdownloader.__download_and_extract_compressed_file__',
                                                                                                                                            'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__filter_for_files__': ( 'testfile_handling.html#testfolderdownloader.__filter_for_files__',
                                                                                                                        'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__get_all_elements_in_all_subdirs__': ( 'testfile_handling.html#testfolderdownloader.__get_all_elements_in_all_subdirs__',
                                                                                                                                       'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__get_download_link_from_path__': ( 'testfile_handling.html#testfolderdownloader.__get_download_link_from_path__',
                                                                                                                                   'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__get_existing_paths__': ( 'testfile_handling.html#testfolderdownloader.__get_existing_paths__',
                                                                                                                          'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__get_missing_paths__': ( 'testfile_handling.html#testfolderdownloader.__get_missing_paths__',
                                                                                                                         'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__init__': ( 'testfile_handling.html#testfolderdownloader.__init__',
                                                                                                            'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.__prepare_download_directory__': ( 'testfile_handling.html#testfolderdownloader.__prepare_download_directory__',
                                                                                                                                  'directlfq/testfile_handling.py'),
                                             'directlfq.testfile_handling.TestFolderDownloader.download_missing_files': ( 'testfile_handling.html#testfolderdownloader.download_missing_files',
                                                                                                                          'directlfq/testfile_handling.py')},
            'directlfq.utils': { 'directlfq.utils.AcquisitionTableHandler': ('utils.html#acquisitiontablehandler', 'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__get_plexDIA_samplenames__': ( 'utils.html#acquisitiontablehandler.__get_plexdia_samplenames__',
                                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__get_reformated_df__': ( 'utils.html#acquisitiontablehandler.__get_reformated_df__',
                                                                                                    'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__get_samplename_without_mtraq_tag__': ( 'utils.html#acquisitiontablehandler.__get_samplename_without_mtraq_tag__',
                                                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__init__': ( 'utils.html#acquisitiontablehandler.__init__',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__reformat_samples_if_necessary': ( 'utils.html#acquisitiontablehandler.__reformat_samples_if_necessary',
                                                                                                              'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.__remove_possible_pre_existing_ml_table__': ( 'utils.html#acquisitiontablehandler.__remove_possible_pre_existing_ml_table__',
                                                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.get_acquisition_info_df': ( 'utils.html#acquisitiontablehandler.get_acquisition_info_df',
                                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.save_dataframe_as_new_acquisition_dataframe': ( 'utils.html#acquisitiontablehandler.save_dataframe_as_new_acquisition_dataframe',
                                                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHandler.update_ml_file_location_in_method_parameters_yaml': ( 'utils.html#acquisitiontablehandler.update_ml_file_location_in_method_parameters_yaml',
                                                                                                                                'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaderFilter': ( 'utils.html#acquisitiontableheaderfilter',
                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaderFilter.__init__': ( 'utils.html#acquisitiontableheaderfilter.__init__',
                                                                                            'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaderFilter.filter_numeric_headers_if_specified': ( 'utils.html#acquisitiontableheaderfilter.filter_numeric_headers_if_specified',
                                                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders': ('utils.html#acquisitiontableheaders', 'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_all_levelnames__': ( 'utils.html#acquisitiontableheaders.__get_all_levelnames__',
                                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_included_levelnames__': ( 'utils.html#acquisitiontableheaders.__get_included_levelnames__',
                                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_ion_headers__': ( 'utils.html#acquisitiontableheaders.__get_ion_headers__',
                                                                                                  'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_ion_headers_grouped__': ( 'utils.html#acquisitiontableheaders.__get_ion_headers_grouped__',
                                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_levelname_mapping_dict': ( 'utils.html#acquisitiontableheaders.__get_levelname_mapping_dict',
                                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_numeric_headers__': ( 'utils.html#acquisitiontableheaders.__get_numeric_headers__',
                                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_ordered_ion_hierarchy__': ( 'utils.html#acquisitiontableheaders.__get_ordered_ion_hierarchy__',
                                                                                                            'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__get_relevant_headers__': ( 'utils.html#acquisitiontableheaders.__get_relevant_headers__',
                                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__init__': ( 'utils.html#acquisitiontableheaders.__init__',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableHeaders.__remove_possible_none_values_from_list__': ( 'utils.html#acquisitiontableheaders.__remove_possible_none_values_from_list__',
                                                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo': ('utils.html#acquisitiontableinfo', 'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__check_if_input_file_is_already_formatted__': ( 'utils.html#acquisitiontableinfo.__check_if_input_file_is_already_formatted__',
                                                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_input_file__': ( 'utils.html#acquisitiontableinfo.__get_input_file__',
                                                                                              'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_input_type_and_config_dict__': ( 'utils.html#acquisitiontableinfo.__get_input_type_and_config_dict__',
                                                                                                              'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_last_ion_level_to_use__': ( 'utils.html#acquisitiontableinfo.__get_last_ion_level_to_use__',
                                                                                                         'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_location_of_original_file__': ( 'utils.html#acquisitiontableinfo.__get_location_of_original_file__',
                                                                                                             'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_original_filename_from_input_file__': ( 'utils.html#acquisitiontableinfo.__get_original_filename_from_input_file__',
                                                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__get_sample_column__': ( 'utils.html#acquisitiontableinfo.__get_sample_column__',
                                                                                                 'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableInfo.__init__': ( 'utils.html#acquisitiontableinfo.__init__',
                                                                                    'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableOutputPaths': ( 'utils.html#acquisitiontableoutputpaths',
                                                                                  'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableOutputPaths.__get_method_parameters_yaml_path__': ( 'utils.html#acquisitiontableoutputpaths.__get_method_parameters_yaml_path__',
                                                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableOutputPaths.__get_output_file_name__': ( 'utils.html#acquisitiontableoutputpaths.__get_output_file_name__',
                                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableOutputPaths.__init__': ( 'utils.html#acquisitiontableoutputpaths.__init__',
                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater': ( 'utils.html#acquisitiontablereformater',
                                                                                 'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__filter_reformated_df_if_necessary__': ( 'utils.html#acquisitiontablereformater.__filter_reformated_df_if_necessary__',
                                                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__filter_reformatted_dataframe_to_relevant_samples__': ( 'utils.html#acquisitiontablereformater.__filter_reformatted_dataframe_to_relevant_samples__',
                                                                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__get_cols_to_use__': ( 'utils.html#acquisitiontablereformater.__get_cols_to_use__',
                                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__init__': ( 'utils.html#acquisitiontablereformater.__init__',
                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__initialize_iterator_with_specified_columns__': ( 'utils.html#acquisitiontablereformater.__initialize_iterator_with_specified_columns__',
                                                                                                                                'directlfq/utils.py'),
                                 'directlfq.utils.AcquisitionTableReformater.__reformatting_function__': ( 'utils.html#acquisitiontablereformater.__reformatting_function__',
                                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater': ('utils.html#longtablereformater', 'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater.__init__': ( 'utils.html#longtablereformater.__init__',
                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater.__initialize_df_iterator__': ( 'utils.html#longtablereformater.__initialize_df_iterator__',
                                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater.__write_reformatted_df_to_file__': ( 'utils.html#longtablereformater.__write_reformatted_df_to_file__',
                                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater.reformat_and_load_acquisition_data_frame': ( 'utils.html#longtablereformater.reformat_and_load_acquisition_data_frame',
                                                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.LongTableReformater.reformat_and_save_acquisition_data_frame': ( 'utils.html#longtablereformater.reformat_and_save_acquisition_data_frame',
                                                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils._get_input_type': ('utils.html#_get_input_type', 'directlfq/utils.py'),
                                 'directlfq.utils.adapt_headers_on_extended_df': ( 'utils.html#adapt_headers_on_extended_df',
                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.adapt_input_df_columns_in_case_of_plexDIA': ( 'utils.html#adapt_input_df_columns_in_case_of_plexdia',
                                                                                                'directlfq/utils.py'),
                                 'directlfq.utils.adapt_subtable': ('utils.html#adapt_subtable', 'directlfq/utils.py'),
                                 'directlfq.utils.add_columns_to_lfq_results_table': ( 'utils.html#add_columns_to_lfq_results_table',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.add_ion_protein_headers_if_applicable': ( 'utils.html#add_ion_protein_headers_if_applicable',
                                                                                            'directlfq/utils.py'),
                                 'directlfq.utils.add_merged_ionnames': ('utils.html#add_merged_ionnames', 'directlfq/utils.py'),
                                 'directlfq.utils.add_mq_protein_group_ids_if_applicable_and_obtain_annotated_file': ( 'utils.html#add_mq_protein_group_ids_if_applicable_and_obtain_annotated_file',
                                                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.annotate_mq_df': ('utils.html#annotate_mq_df', 'directlfq/utils.py'),
                                 'directlfq.utils.check_for_processed_runs_in_results_folder': ( 'utils.html#check_for_processed_runs_in_results_folder',
                                                                                                 'directlfq/utils.py'),
                                 'directlfq.utils.clean_input_filename_if_necessary': ( 'utils.html#clean_input_filename_if_necessary',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.count_fraction_outliers_from_expected_fc': ( 'utils.html#count_fraction_outliers_from_expected_fc',
                                                                                               'directlfq/utils.py'),
                                 'directlfq.utils.create_id_to_protein_df': ('utils.html#create_id_to_protein_df', 'directlfq/utils.py'),
                                 'directlfq.utils.create_or_replace_folder': ('utils.html#create_or_replace_folder', 'directlfq/utils.py'),
                                 'directlfq.utils.determine_id_column_from_input_df': ( 'utils.html#determine_id_column_from_input_df',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.extend_sampleID_column_for_plexDIA_case': ( 'utils.html#extend_sampleid_column_for_plexdia_case',
                                                                                              'directlfq/utils.py'),
                                 'directlfq.utils.extend_sample_allcolumns_for_plexdia_case': ( 'utils.html#extend_sample_allcolumns_for_plexdia_case',
                                                                                                'directlfq/utils.py'),
                                 'directlfq.utils.filter_columns_to_existing_columns': ( 'utils.html#filter_columns_to_existing_columns',
                                                                                         'directlfq/utils.py'),
                                 'directlfq.utils.filter_df_to_minrep': ('utils.html#filter_df_to_minrep', 'directlfq/utils.py'),
                                 'directlfq.utils.filter_input': ('utils.html#filter_input', 'directlfq/utils.py'),
                                 'directlfq.utils.get_all_samples_from_samplemap_df': ( 'utils.html#get_all_samples_from_samplemap_df',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.get_channel_ids_from_config_dict': ( 'utils.html#get_channel_ids_from_config_dict',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.get_condpairname': ('utils.html#get_condpairname', 'directlfq/utils.py'),
                                 'directlfq.utils.get_input_type_and_config_dict': ( 'utils.html#get_input_type_and_config_dict',
                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.get_ionints_from_pd_df': ('utils.html#get_ionints_from_pd_df', 'directlfq/utils.py'),
                                 'directlfq.utils.get_ionname_columns': ('utils.html#get_ionname_columns', 'directlfq/utils.py'),
                                 'directlfq.utils.get_middle_elem': ('utils.html#get_middle_elem', 'directlfq/utils.py'),
                                 'directlfq.utils.get_non_nas_from_pd_df': ('utils.html#get_non_nas_from_pd_df', 'directlfq/utils.py'),
                                 'directlfq.utils.get_nonna_array': ('utils.html#get_nonna_array', 'directlfq/utils.py'),
                                 'directlfq.utils.get_original_file_from_aq_reformat': ( 'utils.html#get_original_file_from_aq_reformat',
                                                                                         'directlfq/utils.py'),
                                 'directlfq.utils.get_protein_column_input_table': ( 'utils.html#get_protein_column_input_table',
                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.get_quality_score_column': ('utils.html#get_quality_score_column', 'directlfq/utils.py'),
                                 'directlfq.utils.get_quant_ids_from_config_dict': ( 'utils.html#get_quant_ids_from_config_dict',
                                                                                     'directlfq/utils.py'),
                                 'directlfq.utils.get_quantitative_columns': ('utils.html#get_quantitative_columns', 'directlfq/utils.py'),
                                 'directlfq.utils.get_relevant_columns': ('utils.html#get_relevant_columns', 'directlfq/utils.py'),
                                 'directlfq.utils.get_relevant_columns_config_dict': ( 'utils.html#get_relevant_columns_config_dict',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.get_results_plot_dir_condpair': ( 'utils.html#get_results_plot_dir_condpair',
                                                                                    'directlfq/utils.py'),
                                 'directlfq.utils.get_sample_ids_from_config_dict': ( 'utils.html#get_sample_ids_from_config_dict',
                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.get_samplenames_from_input_df': ( 'utils.html#get_samplenames_from_input_df',
                                                                                    'directlfq/utils.py'),
                                 'directlfq.utils.get_samples_used_from_samplemap_df': ( 'utils.html#get_samples_used_from_samplemap_df',
                                                                                         'directlfq/utils.py'),
                                 'directlfq.utils.get_samples_used_from_samplemap_file': ( 'utils.html#get_samples_used_from_samplemap_file',
                                                                                           'directlfq/utils.py'),
                                 'directlfq.utils.get_standard_columns_for_input_type': ( 'utils.html#get_standard_columns_for_input_type',
                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.get_type2relevant_cols': ('utils.html#get_type2relevant_cols', 'directlfq/utils.py'),
                                 'directlfq.utils.get_z_from_p_empirical': ('utils.html#get_z_from_p_empirical', 'directlfq/utils.py'),
                                 'directlfq.utils.import_config_dict': ('utils.html#import_config_dict', 'directlfq/utils.py'),
                                 'directlfq.utils.import_data': ('utils.html#import_data', 'directlfq/utils.py'),
                                 'directlfq.utils.index_and_log_transform_input_df': ( 'utils.html#index_and_log_transform_input_df',
                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.invert_dictionary': ('utils.html#invert_dictionary', 'directlfq/utils.py'),
                                 'directlfq.utils.is_plexDIA_table': ('utils.html#is_plexdia_table', 'directlfq/utils.py'),
                                 'directlfq.utils.load_config': ('utils.html#load_config', 'directlfq/utils.py'),
                                 'directlfq.utils.load_input_file_and_de_duplicate_if_evidence': ( 'utils.html#load_input_file_and_de_duplicate_if_evidence',
                                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.load_samplemap': ('utils.html#load_samplemap', 'directlfq/utils.py'),
                                 'directlfq.utils.make_dir_w_existcheck': ('utils.html#make_dir_w_existcheck', 'directlfq/utils.py'),
                                 'directlfq.utils.merge_acquisition_df_parameter_df': ( 'utils.html#merge_acquisition_df_parameter_df',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.merge_channel_and_sample_string': ( 'utils.html#merge_channel_and_sample_string',
                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.merge_protein_and_ion_cols': ( 'utils.html#merge_protein_and_ion_cols',
                                                                                 'directlfq/utils.py'),
                                 'directlfq.utils.merge_protein_cols_and_ion_dict': ( 'utils.html#merge_protein_cols_and_ion_dict',
                                                                                      'directlfq/utils.py'),
                                 'directlfq.utils.merge_sample_id_and_channels': ( 'utils.html#merge_sample_id_and_channels',
                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.parse_channel_from_peptide_column': ( 'utils.html#parse_channel_from_peptide_column',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.prepare_loaded_tables': ('utils.html#prepare_loaded_tables', 'directlfq/utils.py'),
                                 'directlfq.utils.process_with_dask': ('utils.html#process_with_dask', 'directlfq/utils.py'),
                                 'directlfq.utils.reformat_and_save_input_file': ( 'utils.html#reformat_and_save_input_file',
                                                                                   'directlfq/utils.py'),
                                 'directlfq.utils.reformat_and_write_longtable_according_to_config': ( 'utils.html#reformat_and_write_longtable_according_to_config',
                                                                                                       'directlfq/utils.py'),
                                 'directlfq.utils.reformat_and_write_wideformat_table': ( 'utils.html#reformat_and_write_wideformat_table',
                                                                                          'directlfq/utils.py'),
                                 'directlfq.utils.remove_allnan_rows_input_df': ( 'utils.html#remove_allnan_rows_input_df',
                                                                                  'directlfq/utils.py'),
                                 'directlfq.utils.remove_ids_not_occurring_in_mq_df': ( 'utils.html#remove_ids_not_occurring_in_mq_df',
                                                                                        'directlfq/utils.py'),
                                 'directlfq.utils.remove_mtraq_modifications_from_ion_ids': ( 'utils.html#remove_mtraq_modifications_from_ion_ids',
                                                                                              'directlfq/utils.py'),
                                 'directlfq.utils.reshape_input_df': ('utils.html#reshape_input_df', 'directlfq/utils.py'),
                                 'directlfq.utils.save_annotated_mq_df': ('utils.html#save_annotated_mq_df', 'directlfq/utils.py'),
                                 'directlfq.utils.set_mtraq_reduced_ion_column_into_dataframe': ( 'utils.html#set_mtraq_reduced_ion_column_into_dataframe',
                                                                                                  'directlfq/utils.py'),
                                 'directlfq.utils.show_diff': ('utils.html#show_diff', 'directlfq/utils.py'),
                                 'directlfq.utils.sort_and_add_columns': ('utils.html#sort_and_add_columns', 'directlfq/utils.py'),
                                 'directlfq.utils.split_extend_df': ('utils.html#split_extend_df', 'directlfq/utils.py'),
                                 'directlfq.utils.write_chunk_to_file': ('utils.html#write_chunk_to_file', 'directlfq/utils.py')},
            'directlfq.visualizations': { 'directlfq.visualizations.AlphaPeptColorMap': ( 'visualizations.html#alphapeptcolormap',
                                                                                          'directlfq/visualizations.py'),
                                          'directlfq.visualizations.AlphaPeptColorMap.__init__': ( 'visualizations.html#alphapeptcolormap.__init__',
                                                                                                   'directlfq/visualizations.py'),
                                          'directlfq.visualizations.CmapRegistrator': ( 'visualizations.html#cmapregistrator',
                                                                                        'directlfq/visualizations.py'),
                                          'directlfq.visualizations.CmapRegistrator.__init__': ( 'visualizations.html#cmapregistrator.__init__',
                                                                                                 'directlfq/visualizations.py'),
                                          'directlfq.visualizations.CmapRegistrator._define_existing_cmaps': ( 'visualizations.html#cmapregistrator._define_existing_cmaps',
                                                                                                               'directlfq/visualizations.py'),
                                          'directlfq.visualizations.CmapRegistrator.register_colormap': ( 'visualizations.html#cmapregistrator.register_colormap',
                                                                                                          'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter': ( 'visualizations.html#iontracecompararisonplotter',
                                                                                                    'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter.__init__': ( 'visualizations.html#iontracecompararisonplotter.__init__',
                                                                                                             'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._define_protein_dataframes': ( 'visualizations.html#iontracecompararisonplotter._define_protein_dataframes',
                                                                                                                               'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._define_protein_df_after_norm': ( 'visualizations.html#iontracecompararisonplotter._define_protein_df_after_norm',
                                                                                                                                  'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._define_protein_df_before_norm': ( 'visualizations.html#iontracecompararisonplotter._define_protein_df_before_norm',
                                                                                                                                   'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._plot_after_norm': ( 'visualizations.html#iontracecompararisonplotter._plot_after_norm',
                                                                                                                     'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._plot_before_norm': ( 'visualizations.html#iontracecompararisonplotter._plot_before_norm',
                                                                                                                      'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotter._prepare_data_and_plot_ion_traces_before_and_after_normalization': ( 'visualizations.html#iontracecompararisonplotter._prepare_data_and_plot_ion_traces_before_and_after_normalization',
                                                                                                                                                                     'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotterNoDirectLFQTrace': ( 'visualizations.html#iontracecompararisonplotternodirectlfqtrace',
                                                                                                                    'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotterNoDirectLFQTrace.__init__': ( 'visualizations.html#iontracecompararisonplotternodirectlfqtrace.__init__',
                                                                                                                             'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotterNoDirectLFQTrace._plot_after_norm': ( 'visualizations.html#iontracecompararisonplotternodirectlfqtrace._plot_after_norm',
                                                                                                                                     'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceCompararisonPlotterNoDirectLFQTrace._prepare_data_and_plot_ion_traces_before_and_after_normalization': ( 'visualizations.html#iontracecompararisonplotternodirectlfqtrace._prepare_data_and_plot_ion_traces_before_and_after_normalization',
                                                                                                                                                                                     'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer': ( 'visualizations.html#iontracevisualizer',
                                                                                           'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer.__init__': ( 'visualizations.html#iontracevisualizer.__init__',
                                                                                                    'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer._annotate_x_ticks': ( 'visualizations.html#iontracevisualizer._annotate_x_ticks',
                                                                                                             'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer._define_inputs_and_plot_ion_traces': ( 'visualizations.html#iontracevisualizer._define_inputs_and_plot_ion_traces',
                                                                                                                              'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer._define_num_samples': ( 'visualizations.html#iontracevisualizer._define_num_samples',
                                                                                                               'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer._define_prepared_dataframe': ( 'visualizations.html#iontracevisualizer._define_prepared_dataframe',
                                                                                                                      'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer._plot_ion_traces': ( 'visualizations.html#iontracevisualizer._plot_ion_traces',
                                                                                                            'directlfq/visualizations.py'),
                                          'directlfq.visualizations.IonTraceVisualizer.add_median_trace': ( 'visualizations.html#iontracevisualizer.add_median_trace',
                                                                                                            'directlfq/visualizations.py'),
                                          'directlfq.visualizations.MultiOrganismMultiMethodBoxPlot': ( 'visualizations.html#multiorganismmultimethodboxplot',
                                                                                                        'directlfq/visualizations.py'),
                                          'directlfq.visualizations.MultiOrganismMultiMethodBoxPlot.__init__': ( 'visualizations.html#multiorganismmultimethodboxplot.__init__',
                                                                                                                 'directlfq/visualizations.py'),
                                          'directlfq.visualizations.MultiOrganismMultiMethodBoxPlot._add_expected_fold_changes': ( 'visualizations.html#multiorganismmultimethodboxplot._add_expected_fold_changes',
                                                                                                                                   'directlfq/visualizations.py'),
                                          'directlfq.visualizations.MultiOrganismMultiMethodBoxPlot.plot_boxplot': ( 'visualizations.html#multiorganismmultimethodboxplot.plot_boxplot',
                                                                                                                     'directlfq/visualizations.py'),
                                          'directlfq.visualizations.plot_relative_to_median_fcs': ( 'visualizations.html#plot_relative_to_median_fcs',
                                                                                                    'directlfq/visualizations.py'),
                                          'directlfq.visualizations.plot_withincond_fcs': ( 'visualizations.html#plot_withincond_fcs',
                                                                                            'directlfq/visualizations.py')}}}
